
## Installation

You can install `wikipathway2genes` via pip:

`$ pip install wikipathway2genes`

## Usage
Extract gene entries for a specific wikipathway.
<br>usage: `$ wikipathway2genes [-h] -wp WIKIPATHWAY-ID`</br>

## Examples
Extract gene entries for the pathway ACE inhibitor pathway (WP554):
`$ wikipathway2genes -wp WP554`

A tab-separated file will be written out

<i>current version='0.0.5'</i>


